<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

if ( ! function_exists( 'fondness_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Fondness Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function fondness_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'fondness_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'fondness_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Fondness Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function fondness_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'fondness_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'fondness_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Fondness Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function fondness_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'fondness_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'fondness_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Fondness Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function fondness_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'fondness_pro_is_footer_Section_enable' ) ) :
	
	function fondness_pro_is_footer_Section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[footer_section]' )->value() );
}
endif;

if ( ! function_exists( 'fondness_pro_is_footer_menu' ) ) :
	
	function fondness_pro_is_footer_menu( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[footer_menu]' )->value() );
}
endif;

/**
 * Front Page Active Callbacks
 */

/*==================Slider===============*/

/**
 * Check if slider section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[slider_content_type]' )->value();
	return fondness_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[slider_content_type]' )->value();
	return fondness_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[slider_content_type]' )->value();
	return fondness_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================About=====================*/

/**
 * Check if about section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[about_content_type]' )->value();
	return fondness_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[about_content_type]' )->value();
	return fondness_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[about_content_type]' )->value();
	return fondness_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================CTA=====================*/

/**
 * Check if cta section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[cta_content_type]' )->value();
	return fondness_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[cta_content_type]' )->value();
	return fondness_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[cta_content_type]' )->value();
	return fondness_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Our Solution Section=====================*/

/**
 * Check if solution section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_solution_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[solution_section_enable]' )->value() );
}

/**
 * Check if solution section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_solution_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[solution_content_type]' )->value();
	return fondness_pro_is_solution_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if solution section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_solution_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[solution_content_type]' )->value();
	return fondness_pro_is_solution_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if solution section content type is custom.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_solution_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[solution_content_type]' )->value();
	return fondness_pro_is_solution_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Testimonial===================*/

/**
 * Check if testimonial section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[testimonial_content_type]' )->value();
	return fondness_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[testimonial_content_type]' )->value();
	return fondness_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[testimonial_content_type]' )->value();
	return fondness_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Work Section===============*/

/**
 * Check if work section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_work_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[work_section_enable]' )->value() );
}

/**
 * Check if work section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_work_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[work_content_type]' )->value();
	return fondness_pro_is_work_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if work section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_work_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[work_content_type]' )->value();
	return fondness_pro_is_work_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if work section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_work_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[work_content_type]' )->value();
	return fondness_pro_is_work_section_enable( $control ) && ( 'category' == $content_type );
}

/*=========================Latest Posts==================*/

/**
 * Check if latest_posts section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_latest_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[latest_posts_section_enable]' )->value() );
}

/**
 * Check if latest_posts section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_latest_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[latest_posts_content_type]' )->value();
	return fondness_pro_is_latest_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_posts section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_latest_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[latest_posts_content_type]' )->value();
	return fondness_pro_is_latest_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_posts section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_latest_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[latest_posts_content_type]' )->value();
	return fondness_pro_is_latest_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================Subscription===========================*/
/**
 * Check if subscription section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[subscription_section_enable]' )->value() );
}


/*==================Instagram===============*/

/**
 * Check if instagram section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_instagram_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[instagram_section_enable]' )->value() );
}

/**
 * Check if instagram section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_instagram_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[instagram_content_type]' )->value();
	return fondness_pro_is_instagram_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if instagram section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_instagram_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[instagram_content_type]' )->value();
	return fondness_pro_is_instagram_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if instagram section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_instagram_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[instagram_content_type]' )->value();
	return fondness_pro_is_instagram_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Business About=====================*/

/**
 * Check if business_about section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_business_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[business_about_section_enable]' )->value() );
}

/**
 * Check if business_about section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_business_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[business_about_content_type]' )->value();
	return fondness_pro_is_business_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if business_about section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_business_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[business_about_content_type]' )->value();
	return fondness_pro_is_business_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if business_about section content type is custom.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_business_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[business_about_content_type]' )->value();
	return fondness_pro_is_business_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/*===================Counter====================*/

/**
 * Check if counter section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[counter_section_enable]' )->value() );
}

/*=====================Service====================*/

/**
* Check if service section is enabled.
*
* @since Fondness Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function fondness_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[service_section_enable]' )->value() );
}

/**
* Check if service section content type is post.
*
* @since Fondness Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function fondness_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[service_content_type]' )->value();
	return fondness_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
* Check if service section content type is page.
*
* @since Fondness Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function fondness_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[service_content_type]' )->value();
	return fondness_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
* Check if service section content type is category.
*
* @since Fondness Pro 1.0.0
* @param WP_Customize_Control $control WP_Customize_Control instance.
* @return bool Whether the control is active to the current preview.
*/
function fondness_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[service_content_type]' )->value();
	return fondness_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/*===============Team======================*/

/**
 * Check if team section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[team_content_type]' )->value();
	return fondness_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[team_content_type]' )->value();
	return fondness_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[team_content_type]' )->value();
	return fondness_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*========================Gallery====================*/

/**
 * Check if gallery section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[gallery_content_type]' )->value();
	return fondness_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[gallery_content_type]' )->value();
	return fondness_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[gallery_content_type]' )->value();
	return fondness_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/*=========================Featured Posts==================*/

/**
 * Check if featured_posts section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[featured_posts_content_type]' )->value();
	return fondness_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[featured_posts_content_type]' )->value();
	return fondness_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[featured_posts_content_type]' )->value();
	return fondness_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*=========================Popular Posts==================*/

/**
 * Check if popular_posts section is enabled.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'fondness_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[popular_posts_content_type]' )->value();
	return fondness_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[popular_posts_content_type]' )->value();
	return fondness_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since Fondness Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function fondness_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'fondness_pro_theme_options[popular_posts_content_type]' )->value();
	return fondness_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

//all layout 
function fondness_pro_is_all_layout( $control ) {
	$design = $control->manager->get_setting( 'fondness_pro_theme_options[home_layout]' )->value();
	return ( 'all-design' == $design );
}

//pro layout 
function fondness_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'fondness_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

//second layout 
function fondness_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'fondness_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

//fourth layout 
function fondness_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'fondness_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}

//fifth layout 
function fondness_pro_is_fifth_layout( $control ) {
	$design = $control->manager->get_setting( 'fondness_pro_theme_options[home_layout]' )->value();
	return ( 'fifth-design' == $design );
}