<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 * @return array An array of default values
 */

function fondness_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$fondness_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#666',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff6633',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		
		//menu
		'menu_sticky'						=> false,
		'search_icon'						=> true,
		'social_menu_enable'				=> true,
		'menu_transparent'					=> 'absolute-header',
		//'menu_transparent_whole_Site'		=> true,
		//'menu_transparent_except_homepage'	=> false,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'fondness-pro' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> true,
		'footer_section'        		=> true,
		'footer_menu'        			=> true,
		'footer_search'        			=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		'all_sortable'				=> 'about,business_about,counter,cta,featured_posts,gallery,instagram,latest_posts,popular_posts,service,slider,solution,subscription,team,testimonial,work',

		// homepage sections sortable
		'default_sortable' 						=> 'slider,about,cta,solution,testimonial,work,latest_posts,subscription,instagram',

		'second_sortable' 						=> 'slider,business_about,counter,service,cta,team,testimonial,latest_posts,subscription',

		'fourth_sortable' 						=> 'slider,service,cta,business_about,counter,gallery,team,testimonial,latest_posts,subscription',

		'fifth_sortable' 						=> 'slider,business_about,featured_posts,popular_posts,latest_posts,subscription,instagram',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'fondness-pro' ),
		'single_post_hide_banner'		=> false,
		'hide_date' 					=> false,
		'hide_category' 				=> false,
		'hide_banner'					=> false,		
		'blog_page_column'				=> 'col-1',
		'blog_page_post_btn' 			=> esc_html__( 'Read More', 'fondness-pro' ),

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'		=> true,
		'slider_autoplay'			=> false,
		'slider_content_type'		=> 'post',
		'slider_count'				=> 3,
		'slider_excerpt_length'		=> 20,
		'slider_btn_label'			=> esc_html__( 'Explore More', 'fondness-pro' ),

		// About
		'about_section_enable'		=> true,
		'about_content_type'		=> 'post',
		'about_sub_title'			=> esc_html__( 'ABOUT FONDNESS', 'fondness-pro' ),
		'about_short_description'	=> esc_html__( 'Welcome back! Let’s go ahead and talk about some of the highest paying freelance skills in 2021, these can range from technical to non technical skillsets.', 'fondness-pro' ),
		'about_count'				=> 2,
		'about_excerpt_length'		=> 35,
		'about_btn_label1'			=> esc_html__( 'Read More', 'fondness-pro' ),
		'about_btn_label2'			=> esc_html__( 'MORE ABOUT US', 'fondness-pro' ),

		// cta
		'cta_section_enable'		=> true,
		'cta_excerpt_length'		=> 15,
		'cta_content_type'			=> 'post',
		'cta_sub_title'				=> esc_html__( 'DISCOVER MORE', 'fondness-pro' ),
		'cta_title'					=> esc_html__( 'We Create Meaningful Design Product', 'fondness-pro' ),
		'cta_description'			=> esc_html__( 'Welcome back! Let’s go ahead and talk about some of the highest paying freelance skills in 2021.', 'fondness-pro' ),
		'cta_btn_title'				=> esc_html__( 'CALL TO ACTION', 'fondness-pro' ),
		
		// solution
		'solution_section_enable'		=> true,
		'solution_excerpt_length'		=> 35,
		'solution_content_type'			=> 'post',
		'solution_sub_title'			=> esc_html__( 'OUR SOLUTION', 'fondness-pro' ),
		'solution_short_description'	=> esc_html__( 'Welcome back! Let’s go ahead and talk about some of the highest paying freelance skills in 2021.', 'fondness-pro' ),
		'solution_title'				=> esc_html__( 'Make Your Life Easy With This Luxury Design', 'fondness-pro' ),
		'solution_description'			=> esc_html__( 'Based off the national average, a web designer could actually be one of the highest freelancing skills out there. Now, there is alot that encompasses this skill, you should be able to essentially develop websites.', 'fondness-pro' ),
		'solution_btn_title'				=> esc_html__( 'GET STARTED NOW', 'fondness-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_count'				=> 3,	
		'testimonial_excerpt_length'	=> 35,
		'testimonial_content_type'		=> 'category',

		// Work
		'work_section_enable'		=> true,
		'work_sub_title'			=> esc_html__( 'WORK WITH US', 'fondness-pro' ),
		'work_title'				=> esc_html__( 'Craft Digital Products For Business & User Goals', 'fondness-pro' ),
		'work_short_description'	=> esc_html__( 'Let me put it this way, for almost every app / software or game, there are graphic designers behind it to make it visually look better. Some graphic designers can make thousands per project, although this is a pretty competitive field, it’s still a very lucrative field.Based off the national average, a web designer could actually be one of the highest freelancing skills out there. Now, there is alot that encompasses this skill, you should be able to essentially develop websites.', 'fondness-pro' ),
		'work_content_type'			=> 'category',
		'work_count'				=> 13,

		//latest_posts
		'latest_posts_section_enable'	=> true,
		'latest_posts_content_type'		=> 'post',
		'latest_posts_count'			=> 3,
		'latest_posts_sub_title'		=> esc_html__( 'ARTICLE', 'fondness-pro' ),
		'latest_posts_title'			=> esc_html__( 'A Blog Post About Design, Travel & Coffee', 'fondness-pro' ),

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_title'			=> esc_html__( 'Ask Questions and Get Help From The Community', 'fondness-pro' ),
		'subscription_description'		=> esc_html__( 'Sign up with your email address to receive news and updates.', 'fondness-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'fondness-pro' ),

		// Instagram
		'instagram_section_enable'		=> true,
		'instagram_content_type'		=> 'post',
		'instagram_count'				=> 6,

		// business_about
		'business_about_section_enable'			=> true,
		'business_about_content_type'			=> 'page',
		'business_about_subtitle'		=> esc_html__( 'ABOUT', 'fondness-pro' ),
		'business_about_title'					=> esc_html__( 'It Is Never To Late To Learn', 'fondness-pro' ),
		'business_about_description'				=> esc_html__( 'There are people who do not pursue college education during their early days. For those who do, some of them do not continue with graduate education immediately after completing their first degree. These people have several reasons for not pursuing their studies at that time.', 'fondness-pro' ),
		'business_about_btn_title'				=> esc_html__( 'EXPLORE MORE', 'fondness-pro' ),
		'business_about_excerpt_length'			=> 45,

		//counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_title'					=> esc_html('Center Achievements', 'fondness-pro'),
		'counter_subtitle'				=> esc_html('OUR EXPERIENCE', 'fondness-pro'),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_excerpt_length'		=> 15,
		'service_title'					=> esc_html('What We Do', 'fondness-pro'),
		'service_sub_title'				=> esc_html('SERVICES', 'fondness-pro'),

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'				=> 3,
		'team_excerpt_length'		=> 15,
		'team_title'				=> esc_html('Meet Our Staffs', 'fondness-pro'),
		'team_sub_title'			=> esc_html('Team', 'fondness-pro'),
		'team_column'				=> 'col-3',

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 6,
		'gallery_title'					=> esc_html__( 'Center Achievements', 'fondness-pro' ),
		'gallery_subtitle'				=> esc_html__( 'OUR GALLERY', 'fondness-pro' ),

		// featured_posts
		'featured_posts_section_enable'		=> true,
		'featured_posts_content_type'		=> 'category',
		'featured_posts_count'				=> 3,
		'featured_posts_column_layout'		=> 'col-3',


		// popular_posts
		'popular_posts_section_enable'		=> true,
		'popular_posts_content_type'		=> 'category',
		'popular_posts_count'				=> 4,
		'popular_posts_title'				=> esc_html__( 'Popular Posts', 'fondness-pro' ),
		'popular_posts_btn_text'			=> esc_html__( 'Learn More', 'fondness-pro' ),
		'popular_posts_excerpt_length'		=> 20,

	);

	$output = apply_filters( 'fondness_pro_default_theme_options', $fondness_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}