<?php
/**
 * About Us Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add About Us section
$wp_customize->add_section( 'fondness_pro_about_section', array(
	'title'             => esc_html__( 'About Us','fondness-pro' ),
	'description'       => esc_html__( 'About Us Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            fondness_pro_is_default_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// About Us content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[about_section_enable]', array(
	'default'			=> 	$options['about_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[about_section_enable]', array(
	'label'             => esc_html__( 'About Us Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_about_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[about_section_enable]', array(
		'selector'            => '#about-us .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[about_section_enable]',
    ) );
}

// Subtitle setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[about_sub_title]', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default' => $options['about_sub_title'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'fondness_pro_theme_options[about_sub_title]', array(
		'label'             => sprintf( esc_html__( 'Sub Title', 'fondness-pro' ) ),
		'section'        	=> 'fondness_pro_about_section',
		'active_callback' 	=> 'fondness_pro_is_about_section_enable',
		'type'				=> 'text',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[about_sub_title]', array(
		'selector'            => '#about-us p.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[about_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_about_sub_title_partial',
    ) );
}

	// Subtitle setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[about_short_description]', array(
		'sanitize_callback' => 'wp_kses_post',
		'default' => $options['about_short_description'],
		'transport'			=> 'postMessage',
		) );

	$wp_customize->add_control( 'fondness_pro_theme_options[about_short_description]', array(
		'label'             => sprintf( esc_html__( 'Short Description', 'fondness-pro' ) ),
		'section'        	=> 'fondness_pro_about_section',
		'active_callback' 	=> 'fondness_pro_is_about_section_enable',
		'type'				=> 'textarea',
		) );

	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[about_short_description]', array(
		'selector'            => '#about-us div.section-content span',
		'settings'            => 'fondness_pro_theme_options[about_short_description]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_about_short_description_partial',
    ) );
}

// About Us btn label setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[about_btn_label1]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_label1'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[about_btn_label1]', array(
	'label'           	=> esc_html__( 'About Us Button Label', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_about_section',
	'active_callback' 	=> 'fondness_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[about_btn_label1]', array(
		'selector'            => '#about-us a.first',
		'settings'            => 'fondness_pro_theme_options[about_btn_label1]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_about_btn_label1_partial',
    ) );
}

// About Us btn label setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[about_btn_label2]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_btn_label2'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[about_btn_label2]', array(
	'label'           	=> esc_html__( 'About Us Second Button Label', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_about_section',
	'active_callback' 	=> 'fondness_pro_is_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[about_btn_label2]', array(
		'selector'            => '#about-us div.read-more a.second',
		'settings'            => 'fondness_pro_theme_options[about_btn_label2]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_about_btn_label2_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[about_count]', array(
	'default'          	=> $options['about_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_about_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[about_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 2. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_about_section',
	'active_callback'   => 'fondness_pro_is_about_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 2,
		'style' => 'width: 100px;'
		),
) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[about_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['about_excerpt_length'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Us Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in latest posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_about_section',
	'active_callback' 	=> 'fondness_pro_is_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// About Us content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_about_section_enable',
	'choices'			=> array(
            'page'      => esc_html__( 'Page', 'fondness-pro' ),
            'post'      => esc_html__( 'Post', 'fondness-pro' ),
            'category'  => esc_html__( 'Category', 'fondness-pro' ),
        )
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[about_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[about_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_about_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_about_section_content_category_enable'
) ) );

for ( $i = 1; $i <= 2; $i++ ) :

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[about_content_page_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[about_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_about_section',
		'choices'			=> fondness_pro_page_choices(),
		'active_callback'	=> 'fondness_pro_is_about_section_content_page_enable',
	) ) );

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[about_content_post_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[about_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_about_section',
		'choices'			=> fondness_pro_post_choices(),
		'active_callback'	=> 'fondness_pro_is_about_section_content_post_enable',
	) ) );

endfor;