<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'fondness_pro_business_about_section', array(
	'title'             => esc_html__( 'Business About Us','fondness-pro' ),
	'description'       => esc_html__( 'Business About Us Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'	=> function( $control ) {
        return ( 
            fondness_pro_is_second_layout( $control )
            ||
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_fifth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// About content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_section_enable]', array(
	'default'			=> 	$options['business_about_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[business_about_section_enable]', array(
	'label'             => esc_html__( 'Business About Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_business_about_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[business_about_section_enable]', array(
		'selector'            => '#education-about-us .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[business_about_section_enable]',
    ) );
}

// about sub title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[business_about_subtitle]', array(
		'selector'            => '#education-about-us h3.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[business_about_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_business_about_subtitle_partial',
    ) );
}

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['business_about_excerpt_length'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_excerpt_length]', array(
	'label'       		=> esc_html__( 'About Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in about posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
	),
) );

// About content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_content_type]', array(
	'default'          	=> $options['business_about_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_business_about_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'fondness-pro' ),
		'post' 		=> esc_html__( 'Post', 'fondness-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'fondness-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_content_page]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[business_about_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'fondness-pro' ),
	'section'           => 'fondness_pro_business_about_section',
	'choices'			=> fondness_pro_page_choices(),
	'active_callback'	=> 'fondness_pro_is_business_about_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_content_post]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[business_about_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'fondness-pro' ),
	'section'           => 'fondness_pro_business_about_section',
	'choices'			=> fondness_pro_post_choices(),
	'active_callback'	=> 'fondness_pro_is_business_about_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_title'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_title]', array(
	'label'           	=> esc_html__( 'Title', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'text',
) );

// about description setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['business_about_description'],
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_description]', array(
	'label'           	=> esc_html__( 'Description', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// about image setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_image]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fondness_pro_theme_options[business_about_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'fondness-pro' ),
		'section'     		=> 'fondness_pro_business_about_section',
		'active_callback'	=> 'fondness_pro_is_business_about_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['business_about_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[business_about_btn_title]', array(
		'selector'            => '#education-about-us div.read-more a',
		'settings'            => 'fondness_pro_theme_options[business_about_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_business_about_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[business_about_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[business_about_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_business_about_section',
	'active_callback' 	=> 'fondness_pro_is_business_about_section_content_custom_enable',
	'type'				=> 'url',
) );