<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'fondness_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery Posts','fondness-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_gallery_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[gallery_section_enable]', array(
		'selector'            => '#business-gallery-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[gallery_section_enable]',
    ) );
}

// Gallery btn label setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[gallery_subtitle]', array(
	'label'           	=> esc_html__( 'Subtitle', 'fondness-pro' ),
	'section'        	=> 'fondness_pro_gallery_section',
	'active_callback' 	=> 'fondness_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[gallery_subtitle]', array(
		'selector'            => '#business-gallery-section h3.section-subtitle',
		'settings'            => 'fondness_pro_theme_options[gallery_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_gallery_subtitle_partial',
    ) );
}

// gallery title setting and control
$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_title]',
	array(
		'default'       		=> $options['gallery_title'],
		'sanitize_callback'		=> 'sanitize_text_field',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'fondness_pro_theme_options[gallery_title]',
    array(
		'label'      			=> esc_html__( 'Section Title', 'fondness-pro' ),
		'section'    			=> 'fondness_pro_gallery_section',
		'type'		 			=> 'text',
		'active_callback'		=> 'fondness_pro_is_gallery_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[gallery_title]', array(
		'selector'            => '#business-gallery-section h2.section-title',
		'settings'            => 'fondness_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'fondness_pro_gallery_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_gallery_section',
	'active_callback'   => 'fondness_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_gallery_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'fondness-pro' ),
		'post'      => esc_html__( 'Post', 'fondness-pro' ),
		'category'  => esc_html__( 'Category', 'fondness-pro' ),
		),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :
	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_gallery_section',
		'choices'			=> fondness_pro_page_choices(),
		'active_callback'	=> 'fondness_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
		'section'           => 'fondness_pro_gallery_section',
		'choices'			=> fondness_pro_post_choices(),
		'active_callback'	=> 'fondness_pro_is_gallery_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_gallery_section_content_category_enable'
) ) );