<?php
/**
* Service Section options
*
* @package Theme Palace
* @subpackage Fondness Pro
* @since Fondness Pro 1.0.0
*/

// Add Service section
$wp_customize->add_section( 'fondness_pro_service_section', array(
	'title'             => esc_html__( 'Services','fondness-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'	=> function( $control ) {
        return ( 
            fondness_pro_is_second_layout( $control )
            ||
            fondness_pro_is_fourth_layout( $control )
            ||
            fondness_pro_is_all_layout( $control )
        );
    },
) );

// Service content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[service_section_enable]', array(
	'default'			=> 	$options['service_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[service_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_service_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[service_section_enable]', array(
		'selector'            => '#our-services .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[service_section_enable]',
		) );
}

if( in_array( $options['home_layout'], array( 'second-design' ) ) ){

// service title setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[service_sub_title]',
		array(
			'default'       		=> $options['service_sub_title'],
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'fondness_pro_theme_options[service_sub_title]',
		array(
			'label'      			=> esc_html__( 'Section Sub Title', 'fondness-pro' ),
			'section'    			=> 'fondness_pro_service_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'fondness_pro_is_service_section_enable',
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[service_sub_title]', array(
			'selector'            => '#our-services h3.section-subtitle',
			'settings'            => 'fondness_pro_theme_options[service_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'fondness_pro_service_sub_title_partial',
			) );
	}

// service title setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[service_title]',
		array(
			'default'       		=> $options['service_title'],
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'fondness_pro_theme_options[service_title]',
		array(
			'label'      			=> esc_html__( 'Section Title', 'fondness-pro' ),
			'section'    			=> 'fondness_pro_service_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'fondness_pro_is_service_section_enable',
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[service_title]', array(
			'selector'            => '#our-services h2.section-title',
			'settings'            => 'fondness_pro_theme_options[service_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'fondness_pro_service_title_partial',
			) );
	}

}

// Servuce count number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[service_count]', array(
	'default'          	=> $options['service_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_service_count',
	) );

$wp_customize->add_control( 'fondness_pro_theme_options[service_count]', array(
	'label'             => esc_html__( 'Number of services Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 50. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_service_section',
	'active_callback'   => 'fondness_pro_is_service_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 50,
		'style' => 'width: 100px;'
		),
	) );

// long Excerpt length setting and control.
$wp_customize->add_setting( 'fondness_pro_theme_options[service_excerpt_length]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_long_excerpt',
	'default'			=> $options['service_excerpt_length'],
	) );

$wp_customize->add_control( 'fondness_pro_theme_options[service_excerpt_length]', array(
	'label'       		=> esc_html__( 'Service Excerpt Length', 'fondness-pro' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in service posts.', 'fondness-pro' ),
	'section'     		=> 'fondness_pro_service_section',
	'active_callback' 	=> 'fondness_pro_is_service_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Service content type control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[service_content_type]', array(
	'default'          	=> $options['service_content_type'],
	'sanitize_callback' => 'fondness_pro_sanitize_select',
	) );

$wp_customize->add_control( 'fondness_pro_theme_options[service_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'fondness-pro' ),
	'section'           => 'fondness_pro_service_section',
	'type'				=> 'select',
	'active_callback' 	=> 'fondness_pro_is_service_section_enable',
	'choices'			=> array(
		'page'      => esc_html__( 'Page', 'fondness-pro' ),
		'post'      => esc_html__( 'Post', 'fondness-pro' ),
		'category'  => esc_html__( 'Category', 'fondness-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['service_count']; $i++ ) :

// service note control and setting
	$wp_customize->add_setting( 'fondness_pro_theme_options[service_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Fondness_Pro_Icon_Picker( $wp_customize, 'fondness_pro_theme_options[service_content_icon_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'fondness-pro' ), $i ),
	'section'           => 'fondness_pro_service_section',
	'active_callback'	=> 'fondness_pro_is_service_section_enable',
	) ) );

// service pages drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[service_content_page_' . $i . ']', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[service_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'fondness-pro' ), $i ),
	'section'           => 'fondness_pro_service_section',
	'choices'			=> fondness_pro_page_choices(),
	'active_callback'	=> 'fondness_pro_is_service_section_content_page_enable',
	) ) );

// service posts drop down chooser control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[service_content_post_' . $i . ']', array(
	'sanitize_callback' => 'fondness_pro_sanitize_page',
	) );

$wp_customize->add_control( new Fondness_Pro_Dropdown_Chooser( $wp_customize, 'fondness_pro_theme_options[service_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'fondness-pro' ), $i ),
	'section'           => 'fondness_pro_service_section',
	'choices'			=> fondness_pro_post_choices(),
	'active_callback'	=> 'fondness_pro_is_service_section_content_post_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'fondness_pro_theme_options[service_content_category]', array(
	'sanitize_callback' => 'fondness_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Fondness_Pro_Dropdown_Taxonomies_Control( $wp_customize,'fondness_pro_theme_options[service_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'fondness-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'fondness-pro' ),
	'section'           => 'fondness_pro_service_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'fondness_pro_is_service_section_content_category_enable'
	) ) );