<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_about_section() {
    	$options = fondness_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'fondness_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'fondness_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        fondness_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'fondness_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Fondness Pro 1.0.0
    * @param array $input about section details.
    */
    function fondness_pro_get_about_section_details( $input ) {
        $options = fondness_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        $about_count = !empty( $options['about_count'] ) ? $options['about_count'] : 2;
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $about_count; $i++ ) {
                    if ( ! empty( $options['about_content_page_' . $i] ) )
                        $page_ids[] = $options['about_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $about_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $about_count; $i++ ) {
                    if ( ! empty( $options['about_content_post_' . $i] ) )
                        $post_ids[] = $options['about_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $about_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['about_content_category'] ) ? $options['about_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $about_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        $content['details'] = array();

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = fondness_pro_trim_content( $options['about_excerpt_length'] );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content['details'], $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'fondness_pro_filter_about_section_details', 'fondness_pro_get_about_section_details' );


if ( ! function_exists( 'fondness_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_about_section( $content_details = array() ) {
        $options = fondness_pro_get_theme_options();
        $btn_label1 = ! empty( $options['about_btn_label1'] ) ? $options['about_btn_label1'] : '';
        $btn_label2 = ! empty( $options['about_btn_label2'] ) ? $options['about_btn_label2'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
    <div id="fondness_pro_about_section"> 

    
    <div id="about-us" class=" relative page-section same-background">
        <div class="wrapper">

         <?php if ( is_customize_preview()):
                fondness_pro_section_tooltip( 'about-us' );
                endif; ?>

            <?php $i =1; foreach( $content_details['details'] as $content ):
            if ( $i == 1 ) {
                ?>

                <div class="section-header-wrapper clear">
                    <div class="section-header">
                        
                        <?php if( !empty( $options['about_sub_title'] ) ): ?>

                            <p class="section-subtitle"><?php echo esc_html( $options['about_sub_title'] ); ?></p>

                        <?php endif; ?>

                        <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>

                        <?php if( !empty( $content['url'] ) && !empty( $btn_label1 ) ): ?>

                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn first"><?php echo esc_html( $btn_label1 ); ?></a>

                        <?php endif; ?>
                    </div><!-- .section-header -->

                    <div class="section-content">

                        <?php if( !empty( $options['about_short_description'] ) ): ?>

                            <span><?php echo esc_html( $options['about_short_description'] ); ?></span>

                        <?php endif; ?>

                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>

                    </div>
                </div><!-- .section-header-wrapper -->

                <?php }

                $i++; endforeach; ?>

                <?php $j = 1; foreach( $content_details['details'] as $content ):
                if ( $j !== 1 ) {
                    ?>

                    <article class="has-post-thumbnail clear">
                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="hero-banner"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if( !empty( $content['url'] ) && !empty( $btn_label2 ) ): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn second"><?php echo esc_html( $btn_label2 ); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>

                    <?php }
                    $j++; endforeach; ?>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->
        </div>    
    <?php }
endif;