<?php
/**
 * Featured Posts section
 *
 * This is the template for the content of featured_posts section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_featured_posts_section' ) ) :
    /**
    * Add featured_posts section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_featured_posts_section() {
        $options = fondness_pro_get_theme_options();
        // Check if featured_posts is enabled on frontpage
        $featured_posts_enable = apply_filters( 'fondness_pro_section_status', true, 'featured_posts_section_enable' );

        if ( true !== $featured_posts_enable ) {
            return false;
        }
        // Get featured_posts section details
        $section_details = array();
        $section_details = apply_filters( 'fondness_pro_filter_featured_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_posts section now.
        fondness_pro_render_featured_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'fondness_pro_get_featured_posts_section_details' ) ) :
    /**
    * featured_posts section details.
    *
    * @since Fondness Pro 1.0.0
    * @param array $input featured_posts section details.
    */
    function fondness_pro_get_featured_posts_section_details( $input ) {
        $options = fondness_pro_get_theme_options();

        // Content type.
        $featured_posts_content_type  = $options['featured_posts_content_type'];
        $featured_posts_count = !empty( $options['featured_posts_count'] ) ? $options['featured_posts_count'] : 3;
        $content = array();
        switch ( $featured_posts_content_type ) {
            
            case 'page':
                $page_ids = array();
                $author = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_page_' . $i] ) ) :
                        $page_ids[] = $options['featured_posts_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $author = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_post_' . $i] ) ) :
                        $post_ids[] = $options['featured_posts_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_posts_content_category'] ) ? $options['featured_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;
            
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
   
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_posts section content details.
add_filter( 'fondness_pro_filter_featured_posts_section_details', 'fondness_pro_get_featured_posts_section_details' );


if ( ! function_exists( 'fondness_pro_render_featured_posts_section' ) ) :
  /**
   * Start featured_posts section
   *
   * @return string featured_posts content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_featured_posts_section( $content_details = array() ) {
        $options = fondness_pro_get_theme_options();

       if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="fondness_pro_featured_posts_section">
            <div id="featured-posts" class="relative page-section" style="background-image: url('<?php echo esc_url( $options['featured_posts_bg_image'] ); ?>');">
                <div class="wrapper">
                <?php if ( is_customize_preview()):
                fondness_pro_section_tooltip( 'featured-posts' );
                endif; ?>
                    <div class="<?php echo esc_attr( $options['featured_posts_column_layout'] ); ?> clear">
                       
                        <?php foreach ( $content_details as $content ) : ?>

                        <article class="has-post-thumbnail">
                            <div class="featured-post-item">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <div class="entry-meta">
                                        <span class="cat-links">
                                             <?php the_category(',', '', $content['id']); ?>
                                        </span><!-- .cat-links -->
                                    </div><!-- .entry-meta -->

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                </div><!-- .entry-container -->
                            </div><!-- .featured-post-item -->
                        </article>

                        <?php endforeach; ?>

                    </div><!-- .col-3 -->
                </div><!-- .wrapper -->
            </div><!-- #featured-posts -->

        </div>

    <?php }
endif;